<?php
class ControllerModuleCloudinvoice extends Controller {
    private $error = array();
	
    public function index() {
        $this->load->language('module/cloudinvoice');

        $this->document->setTitle($this->language->get('heading_title'));

        $this->load->model('setting/setting');
        
        if (($this->request->server['REQUEST_METHOD'] == 'POST') && $this->validate()) {
            $this->model_setting_setting->editSetting('cloudinvoice', $this->request->post);		
            $this->session->data['success'] = $this->language->get('text_success');
            $this->redirect($this->url->link('module/cloudinvoice', 'token=' . $this->session->data['token'], 'SSL'));
        }

        $this->data = $this->init(); 
        $this->data['statuses'] = json_encode($this->getStatuses());	

        $this->load->language('module/cloudinvoice');

        $this->data['heading_title'] = $this->language->get('heading_title');
        $this->data['text_enabled'] = $this->language->get('text_enabled');
        $this->data['text_disabled'] = $this->language->get('text_disabled');
        $this->data['text_taxes_inv'] = $this->language->get('text_taxes_inv');
        $this->data['text_oc_values'] = $this->language->get('text_oc_values');
        $this->data['text_inv_values'] = $this->language->get('text_inv_values');
        $this->data['text_invoiceprofile'] = $this->language->get('text_invoiceprofile');
        $this->data['text_pricesincltax'] = $this->language->get('text_pricesincltax');
        $this->data['text_invoicedate'] = $this->language->get('text_invoicedate');
        $this->data['text_payment_methods'] = $this->language->get('text_payment_methods');
        
        $this->data['entry_status'] = $this->language->get('entry_status');

        $this->data['text_name'] = $this->language->get('name');
        $this->data['text_URL_platform'] = $this->language->get('URL_platform');
        $this->data['text_Licensekey'] = $this->language->get('Licensekey');
        $this->data['text_Domain'] = $this->language->get('Domain');
        $this->data['text_api_key'] = $this->language->get('api_key');
        $this->data['text_loading'] = $this->language->get('loading');
        $this->data['button_save'] = $this->language->get('button_save');
        $this->data['button_cancel'] = $this->language->get('button_cancel');
        
        if (isset($this->error['warning'])) {
	    $this->data['error_warning'] = $this->error['warning'];
        } else {
	    $this->data['error_warning'] = '';
        }
		
        $this->data['entry_key'] = $this->language->get('entry_key');
        if (isset($this->request->post['cloudinvoice_api_key'])) {
	    $this->data['cloudinvoice_api_key'] = $this->request->post['cloudinvoice_api_key'];
        } else {
	    $this->data['cloudinvoice_api_key'] = $this->config->get('cloudinvoice_api_key');
        }

        $this->data['breadcrumbs'] = array();

        $this->data['breadcrumbs'][] = array(
                                             'text'      => $this->language->get('text_home'),
                                             'href'      => $this->url->link('common/home', 'token=' . $this->session->data['token'], 'SSL'),
                                             'separator' => false
                                       );

        $this->data['breadcrumbs'][] = array(
                                             'text'      => $this->language->get('text_module'),
                                             'href'      => $this->url->link('extension/module', 'token=' . $this->session->data['token'], 'SSL'),
                                             'separator' => ' :: '
                                       );

        $this->data['breadcrumbs'][] = array(
                                             'text'      => $this->language->get('heading_title'),
                                             'href'      => $this->url->link('module/featured', 'token=' . $this->session->data['token'], 'SSL'),
                                             'separator' => ' :: '
                                            );


        $this->data['action'] = $this->url->link('module/cloudinvoice', 'token=' . $this->session->data['token'], 'SSL');

        $this->data['cancel'] = $this->url->link('extension/module', 'token=' . $this->session->data['token'], 'SSL');

        if (isset($this->request->post['order_sent_status'])) {
            $this->data['order_sent_status'] = $this->request->post['order_sent_status'];
        } else {
            $this->data['order_sent_status'] = $this->config->get('order_sent_status');
        }
		
        //Version OpenCart 1.5.6
        $this->load->model('design/layout');
        $this->data['layouts'] = $this->model_design_layout->getLayouts();
        $this->template = 'module/cloudinvoice.tpl';
        $this->children = array(
                                'common/header',
                                'common/footer'
                               );
        $this->response->setOutput($this->render());
    }

    protected function validate() {
        if (!$this->user->hasPermission('modify', 'module/cloudinvoice')) {
            $this->error['warning'] = $this->language->get('error_permission');
        }

        return !$this->error;
    }

    private function getStatuses() {
        $query = $this->db->query("SELECT * FROM `" . DB_PREFIX . "order_status`");
        $statuses = $query->rows;
	
        $arrKeySort = array();
        foreach ($statuses as $st) {
            $arrKeySort[] = $st['order_status_id'];
        }
        array_multisort($arrKeySort, $statuses);
        $returnstats = array();
        foreach ($statuses as $st) {
            $stat = array();
            $stat['id'] = $st['order_status_id'];
            $stat['name'] = $st['name'];
            $returnstats[] = $stat;
        }			
        return $returnstats;
    }

    private function init() {
        $settings = $this->model_setting_setting->getSetting('cloudinvoice'); //To do, retrieve correct values
        if (!isset($settings['cloudinvoiceurl'])) {
            $settings['cloudinvoiceurl'] = 'https://interface.cloudinvoice.company/api/v1';
        }        
        if (!isset($settings['cloudinvoiceapikey'])) {
            $settings['cloudinvoiceapikey'] = '';
        }
        if (!isset($settings['cloudinvoice_api_key'])) {
            $settings['cloudinvoice_api_key'] = '';
        }
        if (!isset($settings['invoicesystem'])) {
            $settings['invoicesystem'] = '';
        }
        return $settings;
    }

}
